@@ -15,20 +15,23 @@
 #'          `has_font()` depends on either the suggested `systemfonts` (preferred) or `pdftools`
 #'          packages being installed.
 #' @examples
-#'  if (requireNamespace("pdftools", quietly = TRUE) && capabilities("cairo")) {
-#'      chars <- c("a", "\u2666")
-#'      fonts <- c("sans", "Sans Noto", "Noto Sans", "Noto Sans Symbols2")
-#'      get_embedded_font(fonts, chars)
+#'  if (requireNamespace("pdftools", quietly = TRUE) &&
+#'      capabilities("cairo") &&
+#'      !piecepackr:::is_cairo_maybe_buggy()) {
+#'    chars <- c("a", "\u2666")
+#'    fonts <- c("sans", "Sans Noto", "Noto Sans", "Noto Sans Symbols2")
+#'    try(get_embedded_font(fonts, chars))
 #'  }
 #'
 #'  if (requireNamespace("systemfonts", quietly = TRUE) ||
-#'      (requireNamespace("pdftools", quietly = TRUE) && capabilities("cairo"))) {
-#'      has_font("Dejavu Sans")
+#'      (requireNamespace("pdftools", quietly = TRUE) &&
+#'       capabilities("cairo")) && !piecepackr:::is_cairo_maybe_buggy()) {
+#'    try(has_font("Dejavu Sans"))
 #'  }
 #' @export
 get_embedded_font <- function(font, char) {
     if (!capabilities("cairo")) {
-        abort("'get_embedded_font()' requires that R has been compiled with 'cairo' support. ")
+        abort("'get_embedded_font()' requires that R has been compiled with 'cairo' support.")
     }
     if (!requireNamespace("pdftools", quietly = TRUE)) {
        if (Sys.which("pdffonts") == "") {
@@ -38,11 +41,20 @@ get_embedded_font <- function(font, char) {
                                    "Please install the suggested R package `{pdftools}`."))
        }
     }
+    if (!isFALSE(getOption("piecepackr.check.cairo")) && is_cairo_maybe_buggy()) {
+        warn(c(sprintf("Your cairographics (version %s) may embed malformed font names.",
+                       grDevices::grSoftVersion()[["cairo"]]),
+               i = "cairographics 1.17.8 is known to embed malformed font names.",
+               i = "cairographics's issue tracker suggests 1.17.4 and 1.17.6 may also do this.",
+               i = "See https://github.com/piecepackr/piecepackr/issues/334 for more info.",
+               i = "These warnings can be disabled via `options(piecepackr.check.cairo = FALSE)`."),
+             class = "piecepackr_buggy_cairo")
+    }
     df <- expand.grid(char, font, stringsAsFactors=FALSE)
     names(df) <- c("char", "requested_font")
     df$embedded_font <- NA
-    for (ii in seq(nrow(df))) {
-        df[ii, 3] <- get_embedded_font_helper(df[ii,2], df[ii,1])
+    for (ii in seq_len(nrow(df))) {
+        df[ii, 3] <- get_embedded_font_helper(df[ii, 2], df[ii, 1])
     }
     df
 }
@@ -56,10 +68,10 @@ get_embedded_font_helper <- function(font, char) {
 
     if (requireNamespace("pdftools", quietly = TRUE)) {
         df <- pdftools::pdf_fonts(file)
-        if(nrow(df) == 0L)
+        if (nrow(df) == 0L)
             embedded_font <- NA # probably some color emoji font used
         else
-            embedded_font <- gsub(".*\\+(.*)", "\\1", df$name)
+            embedded_font <- gsub("^[^+]*\\+(.*)", "\\1", df$name)
     } else {
         pf_output <- system2("pdffonts", file, stdout=TRUE)
         if (length(pf_output) == 2)
@@ -82,7 +94,7 @@ has_font <- function(font) {
         grepl(simplify_font(font), simplify_font(embedded_font))
     } else {
         warn(paste("has_font() needs either the suggested 'systemfonts' package installed",
-                   "or R compiled with 'cairo' support plus the system tool 'pdffonts' installed.",
+                   "or R compiled with 'cairo' support plus the suggested 'pdftools' package installed.",
                    "Conservatively returning `FALSE`."))
         FALSE
     }
@@ -91,3 +103,19 @@ has_font <- function(font) {
 simplify_font <- function(font) {
     tolower(gsub(" ", "", font))
 }
+
+
+# `cairo_pdf()` embedded fontnames with are definitely buggy in cairo 1.17.8
+# they may also be buggy with cairo 1.17.4 and 1.17.6:
+# https://gitlab.freedesktop.org/cairo/cairo/-/issues/449
+is_cairo_maybe_buggy <- function() {
+    cairo_version <- grDevices::grSoftVersion()[["cairo"]]
+    stopifnot("cairographics is not available" = cairo_version != "")
+    cairo_version <- numeric_version(cairo_version)
+    if (cairo_version <= numeric_version("1.17.8") &&
+        cairo_version >= numeric_version("1.17.4")) {
+        TRUE
+    } else {
+        FALSE
+    }
+}
