@@ -6,7 +6,10 @@ expect_equal(to_r(0, 1), 1)
 f <- function(x) assert_suggested("imaginaryPackage")
 expect_error(f(), "You need to install the suggested package")
 
+skip_on_cran()
 skip_if_not_installed("pdftools")
 skip_if(!capabilities("cairo"))
+skip_if(is_cairo_maybe_buggy())
+
 df <- get_embedded_font("sans", c("♥", "♠", "♣", "♦", "🌞", "🌜", "꩜"))
 expect_false(has_font("thisshouldnotexist"))
